@@ -32,21 +32,34 @@ class FileList:
 
 	def merge (self, flist):
 		if isinstance(flist, FileList):
-			flist = flist.get()
+			flist = flist.get(True)
 		elif isinstance(flist, str):
-			flist = [flist]
+			flist = [(flist, '')]
+		else:
+			result = []
+			for f in flist:
+				result.append( ( f, ''))
+			flist = result
+			del result
 
-		for f in flist:
+		for (f, p) in flist:
 			if f in self.__list:
 				continue
 			
-			self.__list.append(f)
+			self.__list.append( (f, p ) )
 		
 		
 		
 		return self.__list
 			
-	def get (self):
+	def get (self, full = False):
+		if not full:
+			result = []
+			for (f, p) in self.__list:
+				result.append(f)
+			
+			return result
+
 		return self.__list
 
 	def __explore(self, dir ):
@@ -63,5 +76,5 @@ class FileList:
 	        	else:
 	        		nfile = tmp[0]
 	        	
-	        	self.__list.append(nfile)
+	        	self.__list.append( (nfile, self.__dir))
 	        
\ No newline at end of file
