@@ -1,4 +1,4 @@
-import os, os.path, shutil, logging, sys, filecmp, stat, re
+import os, os.path, shutil, logging, sys, filecmp, stat, re, time
 from puke.FileList import *
 from puke.Console import *
 from scss import Scss
@@ -178,12 +178,13 @@ def deepcopy(file_list, folder, replace = None):
         else:
             dst_file = os.path.join(folder,os.path.basename(file))
 
-        console.warn("File : " + file +  " dest " + dst_file)
+        #console.warn("File : " + file +  " dest " + dst_file)
 
         res = updatefile(file, dst_file)
 
 
-        if replace:
+        if res and replace:
+
             fh = open(dst_file)
             data = fh.read() + '\n'
         
@@ -191,7 +192,8 @@ def deepcopy(file_list, folder, replace = None):
                 data = data.replace(k, replace.get(k))
 
             fh.close()
-            writefile(dst_file, data)
+            writefile(dst_file, data, os.path.getmtime(file))
+            
 
 
         if res:
@@ -243,7 +245,7 @@ def updatefile(src, dst):
     return copyfile(src, dst)
 
 
-def writefile(dst, content):
+def writefile(dst, content, mtime = None):
     # First test for existance of destination directory
     makedir(os.path.dirname(dst))
     
@@ -252,6 +254,9 @@ def writefile(dst, content):
     handle.write(content)
     handle.close()
 
+    if mtime:
+        os.utime(dst, (time.time(), mtime))
+
 def stats(file_list, title = ""):
     if isinstance(file_list, FileList):
         file_list = file_list.get()
